@@ -2,123 +2,23 @@
 advanced_graph.py - graph class for simple-plotter based on kivy-garden/graph
 Copyright (C) 2020  Thies Hecker
 
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <https://www.gnu.org/licenses/>.
-
-The color table in standard_colors method is taken from matplotlib v3,1,3:
-https://github.com/matplotlib/matplotlib/blob/v3.1.3/lib/matplotlib/_cm.py
-
-See the matplotlib license agreement below.
-
-License agreement for matplotlib versions 1.3.0 and later
-=========================================================
-
-1. This LICENSE AGREEMENT is between the Matplotlib Development Team
-("MDT"), and the Individual or Organization ("Licensee") accessing and
-otherwise using matplotlib software in source or binary form and its
-associated documentation.
-
-2. Subject to the terms and conditions of this License Agreement, MDT
-hereby grants Licensee a nonexclusive, royalty-free, world-wide license
-to reproduce, analyze, test, perform and/or display publicly, prepare
-derivative works, distribute, and otherwise use matplotlib
-alone or in any derivative version, provided, however, that MDT's
-License Agreement and MDT's notice of copyright, i.e., "Copyright (c)
-2012- Matplotlib Development Team; All Rights Reserved" are retained in
-matplotlib  alone or in any derivative version prepared by
-Licensee.
-
-3. In the event Licensee prepares a derivative work that is based on or
-incorporates matplotlib or any part thereof, and wants to
-make the derivative work available to others as provided herein, then
-Licensee hereby agrees to include in any such work a brief summary of
-the changes made to matplotlib .
-
-4. MDT is making matplotlib available to Licensee on an "AS
-IS" basis.  MDT MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR
-IMPLIED.  BY WAY OF EXAMPLE, BUT NOT LIMITATION, MDT MAKES NO AND
-DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS
-FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF MATPLOTLIB
-WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
-
-5. MDT SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF MATPLOTLIB
- FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR
-LOSS AS A RESULT OF MODIFYING, DISTRIBUTING, OR OTHERWISE USING
-MATPLOTLIB , OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF
-THE POSSIBILITY THEREOF.
-
-6. This License Agreement will automatically terminate upon a material
-breach of its terms and conditions.
-
-7. Nothing in this License Agreement shall be deemed to create any
-relationship of agency, partnership, or joint venture between MDT and
-Licensee.  This License Agreement does not grant permission to use MDT
-trademarks or trade name in a trademark sense to endorse or promote
-products or services of Licensee, or any third party.
-
-8. By copying, installing or otherwise using matplotlib ,
-Licensee agrees to be bound by the terms and conditions of this License
-Agreement.
-
-License agreement for matplotlib versions prior to 1.3.0
-========================================================
-
-1. This LICENSE AGREEMENT is between John D. Hunter ("JDH"), and the
-Individual or Organization ("Licensee") accessing and otherwise using
-matplotlib software in source or binary form and its associated
-documentation.
-
-2. Subject to the terms and conditions of this License Agreement, JDH
-hereby grants Licensee a nonexclusive, royalty-free, world-wide license
-to reproduce, analyze, test, perform and/or display publicly, prepare
-derivative works, distribute, and otherwise use matplotlib
-alone or in any derivative version, provided, however, that JDH's
-License Agreement and JDH's notice of copyright, i.e., "Copyright (c)
-2002-2011 John D. Hunter; All Rights Reserved" are retained in
-matplotlib  alone or in any derivative version prepared by
-Licensee.
-
-3. In the event Licensee prepares a derivative work that is based on or
-incorporates matplotlib  or any part thereof, and wants to
-make the derivative work available to others as provided herein, then
-Licensee hereby agrees to include in any such work a brief summary of
-the changes made to matplotlib.
-
-4. JDH is making matplotlib  available to Licensee on an "AS
-IS" basis.  JDH MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR
-IMPLIED.  BY WAY OF EXAMPLE, BUT NOT LIMITATION, JDH MAKES NO AND
-DISCLAIMS ANY REPRESENTATION OR WARRANTY OF MERCHANTABILITY OR FITNESS
-FOR ANY PARTICULAR PURPOSE OR THAT THE USE OF MATPLOTLIB
-WILL NOT INFRINGE ANY THIRD PARTY RIGHTS.
-
-5. JDH SHALL NOT BE LIABLE TO LICENSEE OR ANY OTHER USERS OF MATPLOTLIB
- FOR ANY INCIDENTAL, SPECIAL, OR CONSEQUENTIAL DAMAGES OR
-LOSS AS A RESULT OF MODIFYING, DISTRIBUTING, OR OTHERWISE USING
-MATPLOTLIB , OR ANY DERIVATIVE THEREOF, EVEN IF ADVISED OF
-THE POSSIBILITY THEREOF.
-
-6. This License Agreement will automatically terminate upon a material
-breach of its terms and conditions.
-
-7. Nothing in this License Agreement shall be deemed to create any
-relationship of agency, partnership, or joint venture between JDH and
-Licensee.  This License Agreement does not grant permission to use JDH
-trademarks or trade name in a trademark sense to endorse or promote
-products or services of Licensee, or any third party.
-
-8. By copying, installing or otherwise using matplotlib,
-Licensee agrees to be bound by the terms and conditions of this License
-Agreement.
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
 
 """
 
@@ -160,7 +60,7 @@ class AnnotatedLinePlot(BoxLayout):
         # values which work for lin. and log. scale. These will be recalculated with first plot being added...
         if not xmin:
             xmin = 1.
-        if not ymax:
+        if not xmax:
             xmax = 10.
 
         if not ymin:
@@ -448,37 +348,27 @@ class AnnotatedLinePlot(BoxLayout):
 
     @property
     def standard_colors(self):
-        """list: Returns a list of 18 standard color RGBA values
-
-        The color map table is taken from matplotlib source code:
-        https://github.com/matplotlib/matplotlib/blob/master/lib/matplotlib/_cm.py
+        """list: Returns a list of 16 standard color RGBA values
         """
 
-        _tab20_data = (
-            (0.12156862745098039, 0.4666666666666667, 0.7058823529411765),  # 1f77b4
-            (0.6823529411764706, 0.7803921568627451, 0.9098039215686274),  # aec7e8
-            (1.0, 0.4980392156862745, 0.054901960784313725),  # ff7f0e
-            (1.0, 0.7333333333333333, 0.47058823529411764),  # ffbb78
-            (0.17254901960784313, 0.6274509803921569, 0.17254901960784313),  # 2ca02c
-            (0.596078431372549, 0.8745098039215686, 0.5411764705882353),  # 98df8a
-            (0.8392156862745098, 0.15294117647058825, 0.1568627450980392),  # d62728
-            (1.0, 0.596078431372549, 0.5882352941176471),  # ff9896
-            (0.5803921568627451, 0.403921568627451, 0.7411764705882353),  # 9467bd
-            (0.7725490196078432, 0.6901960784313725, 0.8352941176470589),  # c5b0d5
-            (0.5490196078431373, 0.33725490196078434, 0.29411764705882354),  # 8c564b
-            (0.7686274509803922, 0.611764705882353, 0.5803921568627451),  # c49c94
-            (0.8901960784313725, 0.4666666666666667, 0.7607843137254902),  # e377c2
-            (0.9686274509803922, 0.7137254901960784, 0.8235294117647058),  # f7b6d2
-            (0.4980392156862745, 0.4980392156862745, 0.4980392156862745),  # 7f7f7f
-            (0.7803921568627451, 0.7803921568627451, 0.7803921568627451),  # c7c7c7
-            (0.7372549019607844, 0.7411764705882353, 0.13333333333333333),  # bcbd22
-            (0.8588235294117647, 0.8588235294117647, 0.5529411764705883),  # dbdb8d
-            (0.09019607843137255, 0.7450980392156863, 0.8117647058823529),  # 17becf
-            (0.6196078431372549, 0.8549019607843137, 0.8980392156862745),  # 9edae5
+        # color values created with the create_color_map.py script
+        rgba_values = (
+            (0.800, 0.000, 0.000, 1.0),  # H=0°, S=1.0, V=0.8
+            (0.000, 0.800, 0.800, 1.0),  # H=180°, S=1.0, V=0.8
+            (0.400, 0.800, 0.000, 1.0),  # H=90.0°, S=1.0, V=0.8
+            (0.800, 0.000, 0.600, 1.0),  # H=315.0°, S=1.0, V=0.8
+            (0.000, 0.200, 0.800, 1.0),  # H=225.0°, S=1.0, V=0.8
+            (0.000, 0.800, 0.200, 1.0),  # H=135.0°, S=1.0, V=0.8
+            (0.800, 0.600, 0.000, 1.0),  # H=45.0°, S=1.0, V=0.8
+            (0.400, 0.000, 0.800, 1.0),  # H=270.0°, S=1.0, V=0.8
+            (0.100, 0.800, 0.000, 1.0),  # H=112.5°, S=1.0, V=0.8
+            (0.800, 0.300, 0.000, 1.0),  # H=22.5°, S=1.0, V=0.8
+            (0.700, 0.000, 0.800, 1.0),  # H=292.5°, S=1.0, V=0.8
+            (0.000, 0.500, 0.800, 1.0),  # H=202.5°, S=1.0, V=0.8
+            (0.700, 0.800, 0.000, 1.0),  # H=67.5°, S=1.0, V=0.8
+            (0.800, 0.000, 0.300, 1.0),  # H=337.5°, S=1.0, V=0.8
+            (0.100, 0.000, 0.800, 1.0),  # H=247.5°, S=1.0, V=0.8
+            (0.000, 0.800, 0.500, 1.0),  # H=157.5°, S=1.0, V=0.8
         )
 
-        rgba_values = []
-        for rgb_value in _tab20_data:
-            rgba_values.append((rgb_value[0], rgb_value[1], rgb_value[2], 1))
-
-        return rgba_values
\ No newline at end of file
+        return rgba_values
