@@ -2,25 +2,29 @@
 
 """
 simple_plotter - simple 2d curve plotting front-end and numpy/matplotlib code generator
-Copyright (C) 2018, 2019  Thies Hecker
+Copyright (C) 2019-2020 Thies Hecker
 
-This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <https://www.gnu.org/licenses/>.
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
 """
 
 # import matplotlib.pyplot as plt
 import numpy as np  # needs to be imported, since we launch code with exec which contains numpy statements
-import jsonpickle
 import json
 from jinja2 import Template
 from .code_parser import Code, CodeChecker
@@ -572,15 +576,55 @@ class DataHandler:
                 return [7], [[str(e)]]
             return None, None
 
-    def save_project(self, filename):
+    def save_project(self, filename=None):
         """
         saves project object to JSON file
         """
-        if ".json" not in filename:
+
+        if filename:
+            pass
+        elif self.filename:
+            filename = self.filename
+        else:
+            raise ValueError('Filename not defined!')
+
+        if not filename.endswith('.json'):
             filename += ".json"
 
-        with open(filename, 'w') as f:
-            f.write(jsonpickle.encode(self))
+        data = {
+            'file_format_version': '1.0',
+            'export_csv': self.export_csv,  # for future use...
+            'formula': {
+                'constants': self.formula.constants,
+                'equation': self.formula.equation,
+                'explicit_set_values': self.formula.explicit_set_values,
+                'function_name': self.formula.function_name,
+                'function_unit': self.formula.function_unit,
+                'no_sets': self.formula.no_sets,
+                'set_max_val': self.formula.set_max_val,
+                'set_min_val': self.formula.set_min_val,
+                'set_var_name': self.formula.set_var_name,
+                'set_var_unit': self.formula.set_var_unit,
+                'var_name': self.formula.var_name,
+                'var_unit': self.formula.var_unit
+            },
+            'plot_data': {
+                'end_val': self.plot_data.end_val,
+                'grid': self.plot_data.grid,
+                'no_pts': self.plot_data.no_pts,
+                'plot_title': self.plot_data.plot_title,
+                'start_val': self.plot_data.start_val,
+                'swap_xy': self.plot_data.swap_xy,
+                'user_data': self.plot_data.user_data,  # for future use...
+                'x_log': self.plot_data.x_log,
+                'y_log': self.plot_data.y_log,
+                'y_max': self.plot_data.y_max,
+                'y_min': self.plot_data.y_min
+            }
+        }
+
+        with open(filename, 'w') as file:
+            file.write(json.dumps(data, indent=4))
 
         print('Project saved to '+filename)
 
@@ -594,9 +638,15 @@ class DataHandler:
         json_data = json.loads(read_data)
 
         formula_args = json_data["formula"]
-        del formula_args["py/object"]
         plot_args = json_data["plot_data"]
-        del plot_args["py/object"]
+
+        # check if this is a pre file_format_version 1.0 project file (created with jsonpickle)
+        if 'file_format_version' not in json_data.keys():
+            del formula_args["py/object"]
+            del plot_args["py/object"]
+
+        self.filename = filename
+
         self.formula = Formula(**formula_args)
         self.plot_data = PlotData(**plot_args)
 
